============================================================
``psyclone.psyir.transformations.intrinsics.max2code_trans``
============================================================

.. automodule:: psyclone.psyir.transformations.intrinsics.max2code_trans

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.transformations.intrinsics.max2code_trans
